@@ -61,14 +61,10 @@ def test_get_series(
     assert_equal_data({"a": result}, expected)
 
 
-def test_get_expr_negative_index(
-    request: pytest.FixtureRequest, constructor: Constructor
-) -> None:
+def test_get_expr_negative_index(constructor: Constructor) -> None:
     data = {"a": [[1, 2], [None, 3], [None], None]}
     index = -1
 
-    if any(backend in str(constructor) for backend in ("cudf",)):
-        request.applymarker(pytest.mark.xfail)
     if "pandas" in str(constructor):
         if PANDAS_VERSION < (2, 2):
             pytest.skip()
@@ -82,15 +78,10 @@ def test_get_expr_negative_index(
         df.select(nw.col("a").cast(nw.List(nw.Int32())).list.get(index))
 
 
-def test_get_series_negative_index(
-    request: pytest.FixtureRequest, constructor_eager: ConstructorEager
-) -> None:
+def test_get_series_negative_index(constructor_eager: ConstructorEager) -> None:
     data = {"a": [[1, 2], [None, 3], [None], None]}
     index = -1
 
-    if "cudf" in str(constructor_eager):
-        request.applymarker(pytest.mark.xfail)
-
     if "pandas" in str(constructor_eager):
         if PANDAS_VERSION < (2, 2):
             pytest.skip()
@@ -104,14 +95,10 @@ def test_get_series_negative_index(
         df["a"].list.get(index)
 
 
-def test_get_expr_non_int_index(
-    request: pytest.FixtureRequest, constructor: Constructor
-) -> None:
+def test_get_expr_non_int_index(constructor: Constructor) -> None:
     data = {"a": [[1, 2], [None, 3], [None], None], "index": [0, 1, 0, 0]}
     index = "index"
 
-    if any(backend in str(constructor) for backend in ("cudf",)):
-        request.applymarker(pytest.mark.xfail)
     if "pandas" in str(constructor):
         if PANDAS_VERSION < (2, 2):
             pytest.skip()
@@ -125,15 +112,10 @@ def test_get_expr_non_int_index(
         df.select(nw.col("a").cast(nw.List(nw.Int32())).list.get(index))  # type: ignore[arg-type]
 
 
-def test_get_series_non_int_index(
-    request: pytest.FixtureRequest, constructor_eager: ConstructorEager
-) -> None:
+def test_get_series_non_int_index(constructor_eager: ConstructorEager) -> None:
     data = {"a": [[1, 2], [None, 3], [None], None], "index": [0, 1, 0, 0]}
     index = "index"
 
-    if "cudf" in str(constructor_eager):
-        request.applymarker(pytest.mark.xfail)
-
     if "pandas" in str(constructor_eager):
         if PANDAS_VERSION < (2, 2):
             pytest.skip()
