@@ -25,16 +25,9 @@ def test_drop(constructor: Constructor, to_drop: list[str], expected: list[str])
         assert df.drop(*to_drop).collect_schema().names() == expected
 
 
-@pytest.mark.parametrize(
-    ("strict", "context"),
-    [(True, pytest.raises(ColumnNotFoundError, match="z")), (False, does_not_raise())],
-)
+@pytest.mark.parametrize("strict", [True, False])
 def test_drop_strict(
-    request: pytest.FixtureRequest,
-    constructor: Constructor,
-    context: Any,
-    *,
-    strict: bool,
+    request: pytest.FixtureRequest, constructor: Constructor, *, strict: bool
 ) -> None:
     if "polars_lazy" in str(constructor) and POLARS_VERSION < (1, 0, 0) and strict:
         request.applymarker(pytest.mark.xfail)
@@ -44,6 +37,19 @@ def test_drop_strict(
 
     df = nw.from_native(constructor(data))
 
+    context: Any
+    if strict:
+        if "polars_lazy" in str(constructor):
+            msg = r"^(\"z\"|z)"
+        else:
+            msg = (
+                r"The following columns were not found: \[.*\]"
+                r"\n\nHint: Did you mean one of these columns: \['a', 'b'\]?"
+            )
+        context = pytest.raises(ColumnNotFoundError, match=msg)
+    else:
+        context = does_not_raise()
+
     with context:
         names_out = df.drop(to_drop, strict=strict).collect_schema().names()
         assert names_out == ["b"]
